```{.include}
README.md
```

# Specification

## External includes

Use the following in your markdown file to include any other markdown file:

````markdown
```{.include}
README.md
```
````

The path of the file is with respect to the working directory where `pandoc` is executed.

## Codeblocks

```
Multi line Code blocks are indented 4 spaces and

are formatted

appropriately with > and <.
```

Alternatively, you can use `vimdoc` as the language for the code block to write raw text that will be inserted into the final document.

For example, the following:

````
```vimdoc
You can use codeblocks that have language as `vimdoc` to write raw vimdoc.
```
````

will be rendered verbatim in the generated documentation as below:

```vimdoc
You can use codeblocks that have language as `vimdoc` to write raw vimdoc.
```

This can be used to write any custom whitespace formatted documentation in the generated vimdoc (for mappings, options etc).

Also see [mappings](#mappings) for a Markdown friendly way to write documentation for mappings.

# Title

The first line of the documentation that is generated will look something like this:

```
*panvimdoc.txt*    For VIM - Vi IMproved 8.1       Last change: 2021 August 11
```

# Heading

Main headings are numbered.

<!-- panvimdoc-ignore-start -->

```
==============================================================================
2. Heading                                                 *panvimdoc-heading*

Main headings are numbered.
```

<!-- panvimdoc-ignore-end -->

## Sub Heading 2

Sub headings are upper cased heading.

<!-- panvimdoc-ignore-start -->

```
SUB HEADING 2                                        *panvimdoc-sub-heading-2*

Sub headings are upper cased heading.
```

<!-- panvimdoc-ignore-end -->

Notice that both headings and subheadings have tags.

### Sub Heading 3

Sub headings are upper cased, but do not have tags. They are also not included in the TOC.
They are suffixed with ` ~` which highlights as **bold** text when the file is viewed on GitHub.

## Markdown Links

You can use markdown links in vimdoc. For example, see the [links](#links) section in the generated vim document.

The following markdown:

```markdown
You can link to the tags by using [sub heading 2](#sub-heading-2).
```

is converted to the following vimdoc:

```
You can link to the tags by using |projectName-sub-heading-2|.
```

This way, any links will work in markdown README on GitHub or on the web using anchors AND will work as tags and links in vimdoc.
The anchors are simply dropped in vimdoc inline.
The onus is on the documentation writer to choose the correct anchor for the appropriate Markdown link.

In vim doc tags are created when anchors to the internal document are used.
If the target is an external link, the link is populated in a separate autogenerated [links](#links) section.

If the external link is to the neovim documentation, an internal vim link is generated. See [cursorcolumn](https://neovim.io/doc/user/options.html#'cursorcolumn') or [`completeopt`](https://neovim.io/doc/user/options.html#'completeopt') as an example.
This is excluded from the links section.

Lastly, if the markdown text is a url, the link is not added to the links section and instead is placed inline.

## Mappings

While you can use codeblocks with the language `vimdoc` to insert text in the generated vimdoc, it can be useful to have a markdown friendly way to write documentation for mappings.

Any markdown header of level 4 will be considered as a special header.
This can be used to generate documentation of mappings.
All of the content in curly braces `{...}` that is part of the header is dropped and a tag is created.

For example, the level 4 heading and the contents of the section as follows:

```
#### abc{xyz}

Docstring for abc {xyz}.
```

becomes the following vimdoc:

```
                                                               *projectName-abc*

abc{xyz}                               Docstring for abc {xyz}.
```

Notice that the tag `*projectName-abc` is generated for you:

Additionally, content in square brackets `[...]` is also dropped for creating the tag name.

The heading `### :[range]Command` becomes the tag `*projectName-:Command*`.

See following headings as examples:

#### pv{motion}

Command that operates over {motion} moved.

The following vimdoc mapping is generated:

```
                                                                *projectName-pv*

pv{motion}                             Command that operates over {motion}
                                       moved.

```

#### pvd

Command that takes [count] lines.

The following vimdoc mapping is generated:

```
                                                               *projectName-pvd*

pvd                                    Command that takes [count] lines.

```

#### :[range]CommandName {doc=CommandName}

Command that operates over [range].

The following vimdoc mapping is generated:

```

                                        *projectName-:CommandName* *CommandName*

:[range]CommandName                    Command that operates over [range].
```

You can use `{doc=AdditionalTag}` to generate one additional tag for each header.

#### {Visual}pv

Command that operates over highlighted lines.

The following vimdoc mapping is generated:

```
                                                                *panvimdoc-pv*

{Visual}pv                             Command that operates over highlighted
                                       lines.
```

## Table

Support for markdown tables is also available:

<!-- prettier-ignore-start -->

| Option                             | Background | Default | Description                                                               |
| ---------------------------------- | ---------- | ------- | ------------------------------------------------------------------------- |
| lightness                          | light      | `nil`   | Change background colors lightness. Options: `'bright'`, `'dim'`.         |
| darkness                           | dark       | `nil`   | Change background colors darkness. Options: `'stark'`, `'warm'`.          |
| solid_vert_split                   | both       | `false` | Solid \|hl-VertSplit\| background.                                        |
| solid_line_nr                      | both       | `false` | Solid \|hl-LineNr\| background.                                           |
| solid_float_border                 | both       | `false` | Make \|hl-FloatBorder\| have a more distinguishable background highlight. |
| darken_noncurrent_window           | light      | `false` | Make non-current window background darker than _Normal_.                  |
| lighten_noncurrent_window          | dark       | `false` | Make non-current window background lighter than _Normal_.                 |
| italic_comments                    | both       | `true`  | Make comments italicize.                                                  |
| darken_comments                    | light      | `38`    | Percentage to darken comments relative to Normal bg.                      |
| lighten_comments                   | dark       | `38`    | Percentage to lighten comments relative to Normal bg.                     |
| darken_non_text                    | light      | `25`    | Percentage to darken \|hl-NonText\| relative to Normal bg.                |
| lighten_non_text                   | dark       | `30`    | Percentage to lighten \|hl-NonText\| relative to Normal bg.               |
| darken_line_nr                     | light      | `33`    | Percentage to darken \|hl-LineNr\| relative to Normal bg.                 |
| lighten_line_nr                    | dark       | `35`    | Percentage to lighten \|hl-LineNr\| relative to Normal bg.                |
| darken_cursor_line                 | light      | `3`     | Percentage to darken \|hl-CursorLine\| relative to Normal bg.             |
| lighten_cursor_line                | dark       | `4`     | Percentage to lighten \|hl-CursorLine\| relative to Normal bg.            |
| colorize_diagnostic_underline_text | both       | `false` | Colorize the fg of `DiagnosticUnderline*`.                                |
| transparent_background             | both       | `false` | Make background transparent.                                              |

<!-- prettier-ignore-end -->

<!-- panvimdoc-ignore-start -->

The following gets generated:

```
│              Option              │Background│ Default │                              Description                              │
│lightness                         │light     │nil      │Change background colors lightness. Options: 'bright', 'dim'.          │
│darkness                          │dark      │nil      │Change background colors darkness. Options: 'stark', 'warm'.           │
│solid_vert_split                  │both      │false    │Solid |hl-VertSplit| background.                                       │
│solid_line_nr                     │both      │false    │Solid |hl-LineNr| background.                                          │
│solid_float_border                │both      │false    │Make |hl-FloatBorder| have a more distinguishable background highlight.│
│darken_noncurrent_window          │light     │false    │Make non-current window background darker than _Normal_.               │
│lighten_noncurrent_window         │dark      │false    │Make non-current window background lighter than _Normal_.              │
│italic_comments                   │both      │true     │Make comments italicize.                                               │
│darken_comments                   │light     │38       │Percentage to darken comments relative to Normal bg.                   │
│lighten_comments                  │dark      │38       │Percentage to lighten comments relative to Normal bg.                  │
│darken_non_text                   │light     │25       │Percentage to darken |hl-NonText| relative to Normal bg.               │
│lighten_non_text                  │dark      │30       │Percentage to lighten |hl-NonText| relative to Normal bg.              │
│darken_line_nr                    │light     │33       │Percentage to darken |hl-LineNr| relative to Normal bg.                │
│lighten_line_nr                   │dark      │35       │Percentage to lighten |hl-LineNr| relative to Normal bg.               │
│darken_cursor_line                │light     │3        │Percentage to darken |hl-CursorLine| relative to Normal bg.            │
│lighten_cursor_line               │dark      │4        │Percentage to lighten |hl-CursorLine| relative to Normal bg.           │
│colorize_diagnostic_underline_text│both      │false    │Colorize the fg of DiagnosticUnderline*.                               │
│transparent_background            │both      │false    │Make background transparent.                                           │
```

<!-- panvimdoc-ignore-end -->

## Markdown only content

Content that needs to be presented only in Markdown can be inside `panvimdoc-ignore-{start/end}` blocks:

```
<!-- panvimdoc-ignore-start -->

<details>
    <summary>Vimdoc Ignored Section</summary>

This section will ignored when generating the vimdoc file.
This will only show up in the Markdown file.

</details>

<!-- panvimdoc-ignore-end -->
```

<!-- panvimdoc-ignore-start -->

<details>
    <summary>Vimdoc Ignored Section</summary>

This section will ignored when generating the vimdoc file.
This will only show up in the Markdown file.

</details>

<!-- panvimdoc-ignore-end -->

## Details and summary

You can even use `<details>` and `<summary>` tags for your README.md.

<details>

<summary><b>Summary</b></summary>

This section is the details.

</details>

The `html` tags are dropped and the following output is generated in the vimdoc file.

```
Summary ~

This section is the details.
```

If you are using html `<b> ... </b>` tags, use them on new lines. <b>Inline bold tags</b> will have
a ` ~` appended to the text and that may not be what you want.
